MethodChannelPagepilot class

An implementation of PagepilotPlatform that uses method channels.

Inheritance

Constructors

MethodChannelPagepilot()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
override
getPlatformVersion() → Future<String?>
override
init(Config config) → Future<void>
override
loadTour() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAllTour(dynamic userId) → Future<void>
override
resetTourById(dynamic id, dynamic userId) → Future<void>
override
setUserIdentifier({required String userId, required String tenantId, String? language = "en"}) → void
override
show({required BuildContext context, required String screen, Config? config, String? type, bool showNextAndPreviousButtons = false, required Map keys}) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited